summaryrefslogtreecommitdiffstats
path: root/kjsembed/jsfactory.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:44:01 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:44:01 +0000
commit479f5f799523bffbcc83dff581a2299c047c6fff (patch)
tree186aae707ed02aac6c7cab2fb14e97f72aca5e36 /kjsembed/jsfactory.h
parentf1dbff6145c98324ff82e34448b7483727e8ace4 (diff)
downloadtdebindings-479f5f799523bffbcc83dff581a2299c047c6fff.tar.gz
tdebindings-479f5f799523bffbcc83dff581a2299c047c6fff.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebindings@1157645 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kjsembed/jsfactory.h')
-rw-r--r--kjsembed/jsfactory.h106
1 files changed, 53 insertions, 53 deletions
diff --git a/kjsembed/jsfactory.h b/kjsembed/jsfactory.h
index d2c77cbd..9bef7f82 100644
--- a/kjsembed/jsfactory.h
+++ b/kjsembed/jsfactory.h
@@ -22,9 +22,9 @@
#ifndef KJSEMBEDFACTORY_H
#define KJSEMBEDFACTORY_H
#include "global.h"
-#include <qmap.h>
-#include <qdict.h>
-#include <qstringlist.h>
+#include <tqmap.h>
+#include <tqdict.h>
+#include <tqstringlist.h>
#include <kjs/interpreter.h>
#include <kjs/object.h>
@@ -96,18 +96,18 @@ public:
//
/** Creates an object of the specified class, then returns a proxy. */
- KJS::Object create( KJS::ExecState *exec, const QString &classname, const KJS::List &args );
+ KJS::Object create( KJS::ExecState *exec, const TQString &classname, const KJS::List &args );
/** Creates a proxy object for the specified target with the specified context. */
- KJS::Object createProxy( KJS::ExecState *exec, QObject *target,
+ KJS::Object createProxy( KJS::ExecState *exec, TQObject *target,
const JSObjectProxy *context=0 ) const;
/** Creates a proxy object for the specified target with the specified context. */
- KJS::Object createProxy( KJS::ExecState *exec, QTextStream *target,
+ KJS::Object createProxy( KJS::ExecState *exec, TQTextStream *target,
const JSObjectProxy *context=0 ) const;
/** Creates a proxy object for the specified target with the specified context. */
- KJS::Object createProxy( KJS::ExecState *exec, QEvent *target,
+ KJS::Object createProxy( KJS::ExecState *exec, TQEvent *target,
const JSObjectProxy *context ) const;
@@ -115,12 +115,12 @@ public:
* Registers an opaque proxy factory with the with the factory.
* To add an opaque type to the system you need to provide a factory based off of @ref KJSEmbed::Bindings::JSBindingBase
*/
- void registerOpaqueType( const QString &className, KJSEmbed::Bindings::JSBindingBase *bindingFactory);
+ void registerOpaqueType( const TQString &className, KJSEmbed::Bindings::JSBindingBase *bindingFactory);
/**
* Remove an opaque type from the system.
*/
- void unregisterOpaqueType( const QString &className );
+ void unregisterOpaqueType( const TQString &className );
/**
* When passed an object for a type handled by an Opaque proxy this method
@@ -130,15 +130,15 @@ public:
void extendOpaqueProxy( KJS::ExecState *exec, KJS::Object &proxy) const;
/**
* Registers a QObject proxy factory with the with the factory.
* To add an opaque type to the system you need to provide a factory based off of @ref KJSEmbed::Bindings::JSBindingBase
*/
- void registerObjectType( const QString &className, KJSEmbed::Bindings::JSBindingBase *bindingFactory);
+ void registerObjectType( const TQString &className, KJSEmbed::Bindings::JSBindingBase *bindingFactory);
/**
* Remove an opaque type from the system.
*/
- void unregisterObjectType( const QString &className );
+ void unregisterObjectType( const TQString &className );
/**
* When passed an object for a type handled by an Opaque proxy this method
@@ -158,22 +158,22 @@ public:
* created is the first offer returned by the trader, and will have the
* specified parent and name.
*/
- KParts::ReadOnlyPart *createROPart( const QString &svc, QObject *parent=0, const char *name=0 );
+ KParts::ReadOnlyPart *createROPart( const TQString &svc, TQObject *parent=0, const char *name=0 );
/**
* Creates a ReadOnlyPart that views the specified service type and matches
* the specified constraint.
*/
- KParts::ReadOnlyPart *createROPart( const QString &svc, const QString &constraint,
- QObject *parent=0, const char *name=0 );
+ KParts::ReadOnlyPart *createROPart( const TQString &svc, const TQString &constraint,
+ TQObject *parent=0, const char *name=0 );
/**
* Creates a ReadOnlyPart that views the specified service type and matches
* the specified constraint.
*/
- KParts::ReadOnlyPart *createROPart( const QString &svc, const QString &constraint,
- QObject *parent, const char *name,
- const QStringList &args );
+ KParts::ReadOnlyPart *createROPart( const TQString &svc, const TQString &constraint,
+ TQObject *parent, const char *name,
+ const TQStringList &args );
/**
* Creates a ReadWritePart that edits the specified service type. The
@@ -181,34 +181,34 @@ public:
* created is the first offer returned by the trader, and will have the
* specified parent and name.
*/
- KParts::ReadWritePart *createRWPart( const QString &svc, QObject *parent=0, const char *name=0 );
+ KParts::ReadWritePart *createRWPart( const TQString &svc, TQObject *parent=0, const char *name=0 );
/**
* Creates a ReadWritePart that edits the specified service type and matches
* the specified constraint.
*/
- KParts::ReadWritePart *createRWPart( const QString &svc, const QString &constraint,
- QObject *parent=0, const char *name=0 );
+ KParts::ReadWritePart *createRWPart( const TQString &svc, const TQString &constraint,
+ TQObject *parent=0, const char *name=0 );
/**
* Creates a ReadWritePart that edits the specified service type and matches
* the specified constraint.
*/
- KParts::ReadWritePart *createRWPart( const QString &svc, const QString &constraint,
- QObject *parent, const char *name,
- const QStringList &args );
+ KParts::ReadWritePart *createRWPart( const TQString &svc, const TQString &constraint,
+ TQObject *parent, const char *name,
+ const TQStringList &args );
/**
* Loads the widget defined in the specified .ui file. If the widget
* cannot be created then 0 is returned.
*/
- QWidget *loadUI( const QString &uiFile, QObject *connector=0, QWidget *parent=0, const char *name=0 );
+ TQWidget *loadUI( const TQString &uiFile, TQObject *connector=0, TQWidget *parent=0, const char *name=0 );
/**
* Queries KTrader for a plugin that provides the asked for object binding.
*If the binding was added the object is returned, otherwise a KJS::Null is.
*/
- QStringList listBindingPlugins( KJS::ExecState *exec, KJS::Object &self);
+ TQStringList listBindingPlugins( KJS::ExecState *exec, KJS::Object &self);
//
// Methods that tell the factory how to handle different classes.
//
@@ -216,48 +216,48 @@ public:
* Adds a binding plugin type to the list of available types the factory can create.
*/
void addBindingPluginTypes(KJS::ExecState *exec, KJS::Object &parent);
- bool isBindingPlugin(const QString &classname) const;
+ bool isBindingPlugin(const TQString &classname) const;
/**
* Creates the actual object from the binding plugin.
*/
- KJS::Object createBindingPlugin(KJS::ExecState *exec, const QString &classname, const KJS::List &args );
+ KJS::Object createBindingPlugin(KJS::ExecState *exec, const TQString &classname, const KJS::List &args );
/**
* Returns true iff the factory knows the type of proxy to use for the
* class with the name specified.
*/
- bool isSupported( const QString &clazz ) const;
+ bool isSupported( const TQString &clazz ) const;
/**
* Returns true iff the class with the specified name is handled with the
* QObject proxy type.
*/
- bool isQObject( const QString &clazz ) const;
+ bool isQObject( const TQString &clazz ) const;
/**
* Returns true iff the class with the specified name is handled with the
* value proxy type.
*/
- bool isValue( const QString &clazz ) const;
+ bool isValue( const TQString &clazz ) const;
/**
* Returns true iff the class with the specified name is handled with the
* opaque proxy type.
*/
- bool isOpaque( const QString &clazz ) const;
+ bool isOpaque( const TQString &clazz ) const;
/**
* Returns the ProxyType of the class with the specified name. If the
* named class is not known to the interpreter then TypeInvalid is
* returned.
*/
- uint proxyType( const QString &clazz ) const;
+ uint proxyType( const TQString &clazz ) const;
/**
*Allows adding of an already loaded binding plugin for a certain class type
*
*/
- void addQObjectPlugin(const QString &classname, KJSEmbed::Bindings::JSBindingPlugin* plugin);
+ void addQObjectPlugin(const TQString &classname, KJSEmbed::Bindings::JSBindingPlugin* plugin);
void addBindingsPlugin(KJS::ExecState *exec, KJS::Object &target) const;
@@ -266,58 +266,58 @@ public:
* class. Note that you can remove support for a type by using this method
* with TypeInvalid.
*/
- void addType( const QString &clazz, uint proxytype=JSFactory::TypeQObject );
+ void addType( const TQString &clazz, uint proxytype=JSFactory::TypeQObject );
/** Adds the types defined by the factory to the specified parent. */
void addTypes( KJS::ExecState *exec, KJS::Object &parent );
- QStringList types() const;
+ TQStringList types() const;
protected:
/** Adds custom bindings to the specified proxy object. */
KJS::Object extendProxy( KJS::ExecState *exec, KJS::Object &target ) const;
/** Creates an instance of the named class and returns it in a JSValueProxy. */
- KJS::Object createValue( KJS::ExecState *exec, const QString &cname, const KJS::List &args );
+ KJS::Object createValue( KJS::ExecState *exec, const TQString &cname, const KJS::List &args );
/**
* Creates an instance of a QObject subclass. If the instance cannot be
* created then 0 is returned.
*/
- QObject *create( const QString &classname, QObject *parent=0, const char *name=0 );
+ TQObject *create( const TQString &classname, TQObject *parent=0, const char *name=0 );
/** Creates an instance of the named class and returns it in a JSOpaqueProxy. */
- KJS::Object createOpaque( KJS::ExecState *exec, const QString &cname, const KJS::List &args );
+ KJS::Object createOpaque( KJS::ExecState *exec, const TQString &cname, const KJS::List &args );
- /** Creates an instance of the named binding QObject. */
- QObject *createBinding( const QString &cname, QObject *parent, const char *name );
+ /** Creates an instance of the named binding TQObject. */
+ TQObject *createBinding( const TQString &cname, TQObject *parent, const char *name );
/**
* Creates an instance of the named QObject. This method is only used for
* non-widget objects.
*/
- QObject *createObject( const QString &cname, QObject *parent, const char *name );
+ TQObject *createObject( const TQString &cname, TQObject *parent, const char *name );
/**
* Creates an instance of the named QWidget. Note that this method is only
* used to create widgets that are not supported by QWidgetFactory.
*/
- QWidget *createWidget( const QString &cname, QWidget *parent, const char *name );
+ TQWidget *createWidget( const TQString &cname, TQWidget *parent, const char *name );
private:
/** Adds the types defined by QWidgetFactory to the specified parent. */
void addWidgetFactoryTypes( KJS::ExecState *exec, KJS::Object &parent );
/** Adds support for custom QObject types to the specified parent. */
void addCustomTypes( KJS::ExecState *exec, KJS::Object &parent );
/** Adds support for QObject binding types to the specified parent. */
void addBindingTypes( KJS::ExecState *exec, KJS::Object &parent );
/**
* Adds support for any QObject types that are known about, but have no
* custom support (and no constructor).
*/
void addObjectTypes( KJS::ExecState *exec, KJS::Object &parent );
@@ -329,7 +329,7 @@ private:
private:
KJSEmbedPart *jspart;
JSEventMapper *evmapper;
- QMap<QString,uint> objtypes;
+ TQMap<TQString,uint> objtypes;
class JSFactoryPrivate *d;
};
@@ -130,15 +130,15 @@ public:
void extendOpaqueProxy( KJS::ExecState *exec, KJS::Object &proxy) const;
/**
- * Registers a QObject proxy factory with the with the factory.
+ * Registers a TQObject proxy factory with the with the factory.
* To add an opaque type to the system you need to provide a factory based off of @ref KJSEmbed::Bindings::JSBindingBase
*/
@@ -216,48 +216,48 @@ public:
/**
* Returns true iff the class with the specified name is handled with the
- * QObject proxy type.
+ * TQObject proxy type.
*/
@@ -266,58 +266,58 @@ public:
/**
- * Creates an instance of a QObject subclass. If the instance cannot be
+ * Creates an instance of a TQObject subclass. If the instance cannot be
* created then 0 is returned.
*/
@@ -266,58 +266,58 @@ public:
/**
- * Creates an instance of the named QObject. This method is only used for
+ * Creates an instance of the named TQObject. This method is only used for
* non-widget objects.
*/
@@ -266,58 +266,58 @@ public:
/**
- * Creates an instance of the named QWidget. Note that this method is only
- * used to create widgets that are not supported by QWidgetFactory.
+ * Creates an instance of the named TQWidget. Note that this method is only
+ * used to create widgets that are not supported by TQWidgetFactory.
*/
@@ -266,58 +266,58 @@ public:
private:
- /** Adds the types defined by QWidgetFactory to the specified parent. */
+ /** Adds the types defined by TQWidgetFactory to the specified parent. */
void addWidgetFactoryTypes( KJS::ExecState *exec, KJS::Object &parent );
@@ -266,58 +266,58 @@ public:
void addWidgetFactoryTypes( KJS::ExecState *exec, KJS::Object &parent );
- /** Adds support for custom QObject types to the specified parent. */
+ /** Adds support for custom TQObject types to the specified parent. */
void addCustomTypes( KJS::ExecState *exec, KJS::Object &parent );
@@ -266,58 +266,58 @@ public:
void addCustomTypes( KJS::ExecState *exec, KJS::Object &parent );
- /** Adds support for QObject binding types to the specified parent. */
+ /** Adds support for TQObject binding types to the specified parent. */
void addBindingTypes( KJS::ExecState *exec, KJS::Object &parent );
/**
@@ -266,58 +266,58 @@ public:
void addBindingTypes( KJS::ExecState *exec, KJS::Object &parent );
/**
- * Adds support for any QObject types that are known about, but have no
+ * Adds support for any TQObject types that are known about, but have no
* custom support (and no constructor).
*/